@@ -143,7 +143,9 @@ def import_sample(ctx, manifest_file, project_name, random_pn):
 
 @command(help="Create a new CSA project")
 @argument('project_name', nargs=1)
-@click.option('-o', '--org', default="internal_org", help='Organization that the project belongs to')
+@click.option(
+    '-o', '--org', default="internal_org", help='Organization that the project belongs to'
+)
 @click.option('-r', '--ref', default="hg38", help='Reference data version')
 @pass_context
 def create_project(ctx, project_name, org, ref):
