@@ -25,8 +25,7 @@ def check_project(func):
 @click.group()
 @click.pass_context
 def cli(ctx):
-    """Root subcommand for project api functionality.
-    """
+    """Root subcommand for project api functionality."""
     if ctx.obj.service is None:
         check_profile(ctx)
         ctx.obj.service = ctx.obj.client.service("project")
