@@ -40,6 +40,24 @@ log = logging.getLogger(__name__)
 )
 @option('-d', '--description', help='A human readable description of the job')
 @option('--storage_type', help="Overrides the pipeline storage type for the run")
+@option(
+    '--dedicated_storage_size',
+    help="Overrides the pipeline dedicated storage size for the run. "
+    "format: <num><binary_prefix> ex: 2400Gi",
+)
+@option(
+    '--keep_resources',
+    is_flag=True,
+    help="Instructs the workflow service to exempt resources created for the workflow run from being automatically "
+    "cleaned up after the run has finished.",
+)
+@option(
+    '--mount_job',
+    multiple=True,
+    help='Makes the workflow service mount the working directory of Job id=<value> into this job under folder '
+         '/job/<value>. Can be specified multiple times.',
+    type=int
+)
 @option('-c', '--credentials', help="Credentials to forward to workflow-service", multiple=True)
 @option('--executor_memory_mb', help='Override the memory limit of the nextflow executor')
 @pass_context
@@ -58,6 +76,9 @@ def run(
     trace,
     description,
     storage_type,
+    dedicated_storage_size,
+    keep_resources,
+    mount_job,
     credentials,
     executor_memory_mb,
 ):
@@ -107,7 +128,8 @@ def run(
         dict(params),
     )
 
-
+    if mount_job:
+        log.info(f"Mounting the working directory of the following jobs: {mount_job}")
 
     if not project_name:
         abort("You must specify PROJECT_NAME")
@@ -152,6 +174,9 @@ def run(
             description=description,
             credentials=credentials_struct,
             storage_type=storage_type,
+            dedicated_storage_size=dedicated_storage_size,
+            keep_resources=keep_resources,
+            mount_jobs=mount_job,
             executor_memory_mb=int(executor_memory_mb) if executor_memory_mb else None,
         )
     except ServerError as e:
@@ -164,4 +189,3 @@ def run(
         cmd = ['nextcode', 'workflow', 'job', str(job_id), 'watch']
         echo("Executing %s..." % ' '.join(cmd))
         subprocess.call(cmd)
-
