@@ -7,7 +7,8 @@ from urllib.parse import urlparse
 import requests
 import logging
 
-from nextcodecli.utils import find_aws_credentials, get_logger
+from nextcodecli.utils import get_logger
+from nextcode.credentials import find_aws_credentials
 
 logging.getLogger('botocore').setLevel(logging.WARNING)
 
